@@ -1,16 +1,15 @@
-from mesh.models.sample import Sample
-from bizutil import neo, dbutil
+#from mesh.models.sample import Sample
+#from bizutil import neo #, dbutil
 import pandas as pd
 import time
 #from tradespace import rdd
 from .drivers import cache as drivercache
-from bizutil import hashtricks as ht
-from bizutil import xtime
-from bizutil.format import block
-from bizutil.format import block_right
+#from bizutil import hashtricks as ht
+from .util import xtime
+from .util.format import block
+from .util.format import block_right
 from datetime import datetime
-from bizutil import cass
-from bizutil import tele
+
 
 
 class Vehicle:
@@ -26,6 +25,8 @@ class Vehicle:
         self.deposit_info = None
         self.prev_asks = False
         self.prev_bids = False
+        self.storage = kwargs.get('storage',False)
+
         #self.last_vol = { 'timestamp':datetime.utcnow() , 'val':0 }
     def stat(self):
         print('                        ')
@@ -36,63 +37,53 @@ class Vehicle:
         print('                        ')
 
     def dbref(self , *args , **kwargs):
-        inst = neo.power_merge( "Vehicle" , {'domain':self.domain , 'base':self.base , 'quote':self.quote  } )
-        return inst
+        #inst = neo.power_merge( "Vehicle" , {'domain':self.domain , 'base':self.base , 'quote':self.quote  } )
+        #return inst
+        print(' temp deactivated ')
 
     def market(self):
         try:
             return self.logic.market( self.symbol )
         except Exception as e:
+            print( e )
             self.logic.load_markets()
             return self.logic.market( self.symbol )
 
-    def insert_signal(self , *args , **kwargs):
-        #cass.insert_entry( vals['domain'], vals['symbol'], 'close', series, vals['close'])
+    def insert_entry(self , *args , **kwargs):
+        #.insert_entry( vals['domain'], vals['symbol'], 'close', series, vals['close'])
         #insert_dom_sub_cla_val( 'binanc_rmgold' , 'BTC/USD' , 'close' , 7321 )
         #insert( dom, sub, xcl, val )   # last arg is always value
         #insert( dom , val ) # defaults all other subnamspaces
-
-        # Cassandra wrapper with 2 methods
         # read( ['dom'] ,['sub'], ['xclass'] )   # This will also Defer background process to WRITE Nodes to graph if they don't exist 1
         # write( dom, sub, xcl, val ) # series internal stamp
         # cas.write( x , y , z , val )
-        cass.insert_entry( *args )
+        # IF STORAGE IS ASSIGNED ELSE JUST PRINT 
+        if self.storage: 
+            self.storage.insert_entry( *args )
+        else:
+            print( *args )
 
     def sync( self ,*args , **kwargs):
         try:
-
             vals = self.logic.fetchTicker( self.symbol )
-            print(' Retrieved Vals: ')
-            print( vals )
-            # vals['series']= kwargs.get('time_series', datetime.now().replace(second=0, microsecond=0) )
-            # vals['series']= kwargs.get('time_series', datetime.now().replace(microsecond=0) )
             vals['series']= xtime.series_now()
             vals['domain']=self.domain
-            match_obj={ 'symbol':self.symbol , 'domain':self.domain }
-            #samp = Sample( **vals) #samp.sync()
-            series = xtime.series_now()
+            series = xtime.series_now()              #samp = Sample( **vals) #samp.sync() # Struct for Cython
 
-            #self.insert_signal(vals['domain'], vals['symbol'], 'close', series, vals['close'] )
-
-            cass.insert_entry( vals['domain'], vals['symbol'], 'close', series, vals['close'])
-            cass.insert_entry( vals['domain'], vals['symbol'], 'high', series, vals['high'])
-            cass.insert_entry( vals['domain'], vals['symbol'], 'low', series, vals['low'])
-            cass.insert_entry( vals['domain'], vals['symbol'], 'bid', series, vals['bid'])
-            cass.insert_entry( vals['domain'], vals['symbol'], 'ask', series, vals['ask'])
+            self.insert_entry( vals['domain'], vals['symbol'], 'close', series, vals['close'])
+            self.insert_entry( vals['domain'], vals['symbol'], 'high', series, vals['high'])
+            self.insert_entry( vals['domain'], vals['symbol'], 'low', series, vals['low'])
+            self.insert_entry( vals['domain'], vals['symbol'], 'bid', series, vals['bid'])
+            self.insert_entry( vals['domain'], vals['symbol'], 'ask', series, vals['ask'])
 
             if vals.get('baseVolume') or False :
-                cass.insert_entry( vals['domain'], vals['symbol'], 'bvol', series, vals['baseVolume'])
-
+                self.insert_entry( vals['domain'], vals['symbol'], 'bvol', series, vals['baseVolume'])
             if vals.get('quoteVolume') or False :
-                cass.insert_entry( vals['domain'], vals['symbol'], 'qvol', series, vals['quoteVolume'])
-
+                self.insert_entry( vals['domain'], vals['symbol'], 'qvol', series, vals['quoteVolume'])
             if vals.get('open') or False :
-                cass.insert_entry( vals['domain'], vals['symbol'], 'open', series, vals['open'])
-            #cval = cass.cval( self.domain , self.symbol , 'vol' , xtime.series_now_minus(1) )
-            #cass.insert_entry( vals['domain'], vals['symbol'], 'vol', series, vals['baseVolume'])
-            #cass.insert_entry( vals['domain'], vals['symbol'], 'xvol', series, vals['baseVolume'])
-            ppp=4
+                self.insert_entry( vals['domain'], vals['symbol'], 'open', series, vals['open'])
             return vals
+        
         except Exception as e:
             print( "Vehicle Sync Exception: ",self.domain,' ',self.symbol,' \n Error:', e )
             try:
@@ -118,11 +109,11 @@ class Vehicle:
             if str( index ) in resx_by_time:
                 x1obj = resx_by_time[ str(index) ]
                 h_date = index.to_datetime64()
-                cass.insert_entry( h_dom , h_sym , 'open_h' , h_date , x1obj[1]  )
-                cass.insert_entry( h_dom , h_sym , 'high_h' , h_date , x1obj[2]  )
-                cass.insert_entry( h_dom , h_sym , 'low_h' ,  h_date , x1obj[3]  )
-                cass.insert_entry( h_dom , h_sym , 'close_h', h_date , x1obj[4]  )
-                cass.insert_entry( h_dom , h_sym , 'vol' ,  h_date , x1obj[5]  )
+                self.insert_entry( h_dom , h_sym , 'open_h' , h_date , x1obj[1]  )
+                self.insert_entry( h_dom , h_sym , 'high_h' , h_date , x1obj[2]  )
+                self.insert_entry( h_dom , h_sym , 'low_h' ,  h_date , x1obj[3]  )
+                self.insert_entry( h_dom , h_sym , 'close_h', h_date , x1obj[4]  )
+                self.insert_entry( h_dom , h_sym , 'vol' ,  h_date , x1obj[5]  )
 
     def synco( self , *args ,**kwargs ):
         h_sym = self.symbol
@@ -137,27 +128,28 @@ class Vehicle:
         insert_count=0
         for rec in reversed(resx):
             h_date=datetime.fromtimestamp( rec[0]/1000 )
-            cass.insert_entry( h_dom , h_sym , 'open_h' , h_date , rec[1]  )
-            cass.insert_entry( h_dom , h_sym , 'high_h' , h_date , rec[2]  )
-            cass.insert_entry( h_dom , h_sym , 'low_h' ,  h_date , rec[3]  )
-            cass.insert_entry( h_dom , h_sym , 'close_h', h_date , rec[4]  )
-            cass.insert_entry( h_dom , h_sym , 'vol' ,  h_date , rec[5]  )
+            self.insert_entry( h_dom , h_sym , 'open_h' , h_date , rec[1]  )
+            self.insert_entry( h_dom , h_sym , 'high_h' , h_date , rec[2]  )
+            self.insert_entry( h_dom , h_sym , 'low_h' ,  h_date , rec[3]  )
+            self.insert_entry( h_dom , h_sym , 'close_h', h_date , rec[4]  )
+            self.insert_entry( h_dom , h_sym , 'vol' ,  h_date , rec[5]  )
             insert_count+=1
             if insert_count > 3:
                 break
         return resx
 
     def impute_derivatives(self , *args, **kwargs ):
-        if('close' in args[0] ):
-            vals = args[0]
-            neo.power_upsert('Vehicle', {'domain':self.domain,'symbol':self.symbol} , {'close':vals['close'] })
+        #if('close' in args[0] ):
+        #    vals = args[0]
+        #    neo.power_upsert('Vehicle', {'domain':self.domain,'symbol':self.symbol} , {'close':vals['close'] })
+        pass
 
-    def samples(self,*args, **kwargs):
+    def samplesx(self,*args, **kwargs):
         #from models import Sample
-        # should now be CASS somethingf
-        session = dbutil.get_store()
-        rows = session.execute("""SELECT * FROM sample WHERE domain=%s AND symbol=%s""" , ( self.domain , self.symbol ) )
-        return rows
+        #session = dbutil.get_store()
+        #rows = session.execute("""SELECT * FROM sample WHERE domain=%s AND symbol=%s""" , ( self.domain , self.symbol ) )
+        #return rows
+        print(' no longer implemented ')
 
     def ops(self):
         # CONVERSIONS
@@ -385,7 +377,7 @@ class Vehicle:
         # 'ob_topvol_fresh_bids'
         # 'ob_topvol_fresh_asks'
         # 'ob_big_vol_10_fresh_asks'
-        # TO JSON IN  # doesn't work cause Cassandra type field
+        # TO JSON IN  # doesn't work cause andra type field
         #meta_obj['ob_bids_json']=df_bids.to_json(orient='records')
         #meta_obj['ob_asks_json']=df_asks.to_json(orient='records')
         #df =  self.p
@@ -544,7 +536,7 @@ class Vehicle:
         # PLACE ORDER
         self.logic.verbose=True
         series = xtime.series_now()
-        self.insert_signal( domain_alias , self.symbol , 'order_attempt',   series, 1 )
+        self.insert_entry( domain_alias , self.symbol , 'order_attempt',   series, 1 )
         res = self.logic.create_order( self.symbol , 'limit' , 'buy' , amount_minus_fee , target_price , {'timeInForce':'IOC'} )
 
         #if self.logic.has['createMarketOrder']:
@@ -558,13 +550,13 @@ class Vehicle:
 
         # RECORD ORDER
         if res['status']=='closed':
-            self.insert_signal( domain_alias , self.symbol , 'order_side',   series, 1 )
-            self.insert_signal( domain_alias , self.symbol , 'order_target', series, target_price )
-            self.insert_signal( domain_alias , self.symbol , 'order_price',  series, res['price'] )
-            self.insert_signal( domain_alias , self.symbol , 'order_quant',  series, res['amount'] )
+            self.insert_entry( domain_alias , self.symbol , 'order_side',   series, 1 )
+            self.insert_entry( domain_alias , self.symbol , 'order_target', series, target_price )
+            self.insert_entry( domain_alias , self.symbol , 'order_price',  series, res['price'] )
+            self.insert_entry( domain_alias , self.symbol , 'order_quant',  series, res['amount'] )
         else:
-            self.insert_signal( domain_alias , self.symbol , 'order_side', series, 1 )
-            self.insert_signal( domain_alias , self.symbol , 'order_target', series, target_price )
+            self.insert_entry( domain_alias , self.symbol , 'order_side', series, 1 )
+            self.insert_entry( domain_alias , self.symbol , 'order_target', series, target_price )
         return res
     def exit(self , amount=False ):
         domain_alias = self.domain+'_'+self.alias
@@ -594,7 +586,7 @@ class Vehicle:
         # PLACE ORDER
         self.logic.verbose=True
         series = xtime.series_now()
-        self.insert_signal( domain_alias , self.symbol , 'order_attempt',   series, -1 )
+        self.insert_entry( domain_alias , self.symbol , 'order_attempt',   series, -1 )
         res = self.logic.create_order( self.symbol , 'limit' , 'sell' , target_amount , target_price , {'timeInForce':'IOC'} )
         #res = self.logic.create_order( self.symbol , 'limit' , 'buy' , target_amount , target_price , {'timeInForce':'IOC'} )
         #if self.logic.has['createMarketOrder']:
@@ -606,13 +598,13 @@ class Vehicle:
 
         # RECORD ORDER
         if res['status']=='closed':
-            self.insert_signal( domain_alias , self.symbol , 'order_side', series, -1 )
-            self.insert_signal( domain_alias , self.symbol , 'order_target', series, target_price )
-            self.insert_signal( domain_alias , self.symbol , 'order_price',  series, res['price'] )
-            self.insert_signal( domain_alias , self.symbol , 'order_quant',  series, res['amount'] )
+            self.insert_entry( domain_alias , self.symbol , 'order_side', series, -1 )
+            self.insert_entry( domain_alias , self.symbol , 'order_target', series, target_price )
+            self.insert_entry( domain_alias , self.symbol , 'order_price',  series, res['price'] )
+            self.insert_entry( domain_alias , self.symbol , 'order_quant',  series, res['amount'] )
         else:
-            self.insert_signal( domain_alias , self.symbol , 'order_side', series, -1 )
-            self.insert_signal( domain_alias , self.symbol , 'order_target', series, target_price )
+            self.insert_entry( domain_alias , self.symbol , 'order_side', series, -1 )
+            self.insert_entry( domain_alias , self.symbol , 'order_target', series, target_price )
         return res
 
         # Gotta Save some record of the Transaction intent # Ideal=
@@ -668,7 +660,7 @@ class Vehicle:
         # PLACE ORDER
         self.logic.verbose=True
         series = xtime.series_now()
-        #self.insert_signal( domain_alias , self.symbol , 'order_attempt',   series, 1 )
+        #self.insert_entry( domain_alias , self.symbol , 'order_attempt',   series, 1 )
         #res = self.logic.create_order( self.symbol , 'limit' , 'buy' , amount_minus_fee , target_price , {'timeInForce':'IOC'} )
 
         if self.logic.has['createMarketOrder']:
@@ -680,13 +672,13 @@ class Vehicle:
 
         # RECORD ORDER
         if res['status']=='closed':
-            self.insert_signal( domain_alias , self.symbol , 'order_side',   series, 1 )
-            self.insert_signal( domain_alias , self.symbol , 'order_target', series, target_price )
-            self.insert_signal( domain_alias , self.symbol , 'order_price',  series, res['price'] )
-            self.insert_signal( domain_alias , self.symbol , 'order_quant',  series, res['amount'] )
+            self.insert_entry( domain_alias , self.symbol , 'order_side',   series, 1 )
+            self.insert_entry( domain_alias , self.symbol , 'order_target', series, target_price )
+            self.insert_entry( domain_alias , self.symbol , 'order_price',  series, res['price'] )
+            self.insert_entry( domain_alias , self.symbol , 'order_quant',  series, res['amount'] )
         else:
-            self.insert_signal( domain_alias , self.symbol , 'order_side', series, 1 )
-            self.insert_signal( domain_alias , self.symbol , 'order_target', series, target_price )
+            self.insert_entry( domain_alias , self.symbol , 'order_side', series, 1 )
+            self.insert_entry( domain_alias , self.symbol , 'order_target', series, target_price )
         return res
     def dump( self , amount=False ):
         domain_alias = self.domain+'_'+self.alias
@@ -712,7 +704,7 @@ class Vehicle:
         # PLACE ORDER
         self.logic.verbose=True
         series = xtime.series_now()
-        self.insert_signal( domain_alias , self.symbol , 'order_attempt',   series, -1 )
+        self.insert_entry( domain_alias , self.symbol , 'order_attempt',   series, -1 )
         #res = self.logic.create_order( self.symbol , 'limit' , 'sell' , target_amount , target_price , {'timeInForce':'IOC'} )
         #res = self.logic.create_order( self.symbol , 'limit' , 'buy' , target_amount , target_price , {'timeInForce':'IOC'} )
         if self.logic.has['createMarketOrder']:
@@ -726,13 +718,13 @@ class Vehicle:
         #self.record_transaction_result()
         # RECORD ORDER
         if res['status']=='closed':
-            self.insert_signal( domain_alias , self.symbol , 'order_side', series, -1 )
-            self.insert_signal( domain_alias , self.symbol , 'order_target', series, target_price )
-            self.insert_signal( domain_alias , self.symbol , 'order_price',  series, res['price'] )
-            self.insert_signal( domain_alias , self.symbol , 'order_quant',  series, res['amount'] )
+            self.insert_entry( domain_alias , self.symbol , 'order_side', series, -1 )
+            self.insert_entry( domain_alias , self.symbol , 'order_target', series, target_price )
+            self.insert_entry( domain_alias , self.symbol , 'order_price',  series, res['price'] )
+            self.insert_entry( domain_alias , self.symbol , 'order_quant',  series, res['amount'] )
         else:
-            self.insert_signal( domain_alias , self.symbol , 'order_side', series, -1 )
-            self.insert_signal( domain_alias , self.symbol , 'order_target', series, target_price )
+            self.insert_entry( domain_alias , self.symbol , 'order_side', series, -1 )
+            self.insert_entry( domain_alias , self.symbol , 'order_target', series, target_price )
         return res
 
     def convert_maximum_to(self , target_base_in):
@@ -866,10 +858,10 @@ class Vehicle:
     ########################## GRAPH BUILDERS 
     @classmethod
     def merge( self,   *args , **kwargs ):
-        instance = Vehicle( *args , **kwargs )
-        node_data = ht.erase_keys( kwargs , ['apiKey','key','secret','password','passphrase'] )
-        n = neo.hash_merge( "Vehicle" , {'domain':kwargs['domain'] , 'symbol':kwargs['symbol'] } , node_data )
-        instance.node = n
+        #instance = Vehicle( *args , **kwargs )
+        #node_data = ht.erase_keys( kwargs , ['apiKey','key','secret','password','passphrase'] )
+        #n = neo.hash_merge( "Vehicle" , {'domain':kwargs['domain'] , 'symbol':kwargs['symbol'] } , node_data )
+        #instance.node = n
         return instance
 
     def caps(self , allowed_list ):
